@@ -53,7 +53,7 @@
 /*
   Define declarations.
 */
-#define MagickPagesize(name,geometry) { (name), sizeof(name)-1, (geometry) }
+#define MagickPagesize(name,geometry) { name, sizeof(name)-1, geometry }
 
 /*
   Structure declarations.
@@ -85,25 +85,25 @@ static const PageInfo
     MagickPagesize("4A0", "4768x6741"),
     MagickPagesize("2A0", "3370x4768"),
     MagickPagesize("a0", "2384x3370"),
+    MagickPagesize("a10", "74x105"),
     MagickPagesize("a1", "1684x2384"),
     MagickPagesize("a2", "1191x1684"),
     MagickPagesize("a3", "842x1191"),
-    MagickPagesize("a4", "595x842"),
     MagickPagesize("a4small", "595x842"),
+    MagickPagesize("a4", "595x842"),
     MagickPagesize("a5", "420x595"),
     MagickPagesize("a6", "298x420"),
     MagickPagesize("a7", "210x298"),
     MagickPagesize("a8", "147x210"),
     MagickPagesize("a9", "105x147"),
-    MagickPagesize("a10", "74x105"),
     MagickPagesize("archa", "648x864"),
     MagickPagesize("archb", "864x1296"),
     MagickPagesize("archC", "1296x1728"),
     MagickPagesize("archd", "1728x2592"),
     MagickPagesize("arche", "2592x3456"),
     MagickPagesize("b0", "2920x4127"),
-    MagickPagesize("b1", "2064x2920"),
     MagickPagesize("b10", "91x127"),
+    MagickPagesize("b1", "2064x2920"),
     MagickPagesize("b2", "1460x2064"),
     MagickPagesize("b3", "1032x1460"),
     MagickPagesize("b4", "729x1032"),
@@ -129,8 +129,8 @@ static const PageInfo
     MagickPagesize("folio", "612x936"),
     MagickPagesize("halfletter", "396x612"),
     MagickPagesize("isob0", "2835x4008"),
-    MagickPagesize("isob1", "2004x2835"),
     MagickPagesize("isob10", "88x125"),
+    MagickPagesize("isob1", "2004x2835"),
     MagickPagesize("isob2", "1417x2004"),
     MagickPagesize("isob3", "1001x1417"),
     MagickPagesize("isob4", "709x1001"),
@@ -148,8 +148,8 @@ static const PageInfo
     MagickPagesize("jisb6", "128x182"),
     MagickPagesize("ledger", "1224x792"),
     MagickPagesize("legal", "612x1008"),
-    MagickPagesize("letter", "612x792"),
     MagickPagesize("lettersmall", "612x792"),
+    MagickPagesize("letter", "612x792"),
     MagickPagesize("monarch", "279x540"),
     MagickPagesize("quarto", "610x780"),
     MagickPagesize("statement", "396x612"),
@@ -555,14 +555,14 @@ MagickExport void GravityAdjustGeometry(const size_t width,
     case EastGravity:
     case SouthEastGravity:
     {
-      region->x=(ssize_t) (width-region->width-region->x);
+      region->x=CastDoubleToLong((double) width-region->width-region->x);
       break;
     }
     case NorthGravity:
     case SouthGravity:
     case CenterGravity:
     {
-      region->x+=(ssize_t) (width/2-region->width/2);
+      region->x=CastDoubleToLong(width/2.0-region->width/2.0+region->x);
       break;
     }
     case ForgetGravity:
@@ -578,14 +578,14 @@ MagickExport void GravityAdjustGeometry(const size_t width,
     case SouthGravity:
     case SouthEastGravity:
     {
-      region->y=(ssize_t) (height-region->height-region->y);
+      region->y=CastDoubleToLong((double) height-region->height-region->y);
       break;
     }
     case EastGravity:
     case WestGravity:
     case CenterGravity:
     {
-      region->y+=(ssize_t) (height/2-region->height/2);
+      region->y=CastDoubleToLong(height/2.0-region->height/2.0+region->y);
       break;
     }
     case ForgetGravity:
@@ -1219,7 +1219,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
           geometry_info->sigma=geometry_info->xi;
           geometry_info->xi=0.0;
           flags|=SigmaValue;
-          flags&=(~XiValue);
+          flags&=(unsigned int) (~XiValue);
         }
       else
         if ((flags & ChiValue) == 0)
@@ -1231,7 +1231,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
             geometry_info->xi=geometry_info->psi;
             flags|=SigmaValue;
             flags|=XiValue;
-            flags&=(~PsiValue);
+            flags&=(unsigned int) (~PsiValue);
           }
         else
           {
@@ -1244,7 +1244,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
             flags|=SigmaValue;
             flags|=XiValue;
             flags|=PsiValue;
-            flags&=(~ChiValue);
+            flags&=(unsigned int) (~ChiValue);
           }
     }
   if ((flags & PercentValue) != 0)
@@ -1515,8 +1515,8 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
       scale.y=geometry_info.sigma;
       if ((percent_flags & SigmaValue) == 0)
         scale.y=scale.x;
-      *width=(size_t) floor(scale.x*stasis_width/100.0+0.5);
-      *height=(size_t) floor(scale.y*stasis_height/100.0+0.5);
+      *width=CastDoubleToUnsigned(scale.x*stasis_width/100.0+0.5);
+      *height=CastDoubleToUnsigned(scale.y*stasis_height/100.0+0.5);
       stasis_width=(*width);
       stasis_height=(*height);
     }
@@ -1536,7 +1536,7 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
       if (geometry_ratio >= image_ratio)
         {
           *width=stasis_width;
-          *height=(size_t) floor((double) (PerceptibleReciprocal(
+          *height=CastDoubleToUnsigned((double) (PerceptibleReciprocal(
             geometry_ratio)*stasis_height*image_ratio)+0.5);
         }
       else
